@@ -35,6 +35,19 @@ import pytz
 import random
 import string
 import webbrowser
+def today(format="%Y-%m-%d"):
+    return datetime.datetime.now().strftime(format)
+def rename(old, new):
+    if os.path.exists(old):
+        os.rename(old, new)
+        return True
+    return False
+def clear_clipboard():
+    pyperclip.copy("")
+def random_filename(ext=".mp3", prefix="file"):
+    return f"{prefix}_{random.randint(1000,9999)}{ext}"
+def list_files(folder="."):
+    return [f for f in os.listdir(folder) if os.path.isfile(os.path.join(folder,f))]
 def to_upper(text):
     return text.upper()
 def open_web(url):
@@ -250,7 +263,7 @@ def clock(unit):
     else:
         return "Invalid unit"
 __all__ = [
-    "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary","open_web"
-    "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "shapecursor","run_app", "get_file_size", "generate_password", "google_search",
-    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak", "to_upper"
+    "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary","open_web", "rename", "today",
+    "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "shapecursor","run_app", "get_file_size", "generate_password", "google_search", "random_filename",
+    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak", "to_upper", "list_files"
 ]
